==> haskell-cabal-doctest-1.0.6-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.6
id: cabal-doctest-1.0.6-FPXFVTdxwr34wuwyQZ4M63
key: cabal-doctest-1.0.6-FPXFVTdxwr34wuwyQZ4M63
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Extra.Doctest
abi: dff4998a568e479ca6f3e34c39208d34
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-doctest-1.0.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-doctest-1.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cabal-doctest-1.0.6
hs-libraries: HScabal-doctest-1.0.6-FPXFVTdxwr34wuwyQZ4M63
depends:
    base-4.10.1.0 Cabal-2.0.1.0 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-doctest-1.0.6-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.6
id: cabal-doctest-1.0.6-E57gwmEN5fa2uY0bq8bb44
key: cabal-doctest-1.0.6-E57gwmEN5fa2uY0bq8bb44
license: BSD-3-Clause
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
abi: e3108244479256eec3910f006ebdb24a
exposed: True
exposed-modules:
    Distribution.Extra.Doctest
import-dirs: /usr/lib/ghc-8.4.3/site-local/cabal-doctest-1.0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/cabal-doctest-1.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cabal-doctest-1.0.6
hs-libraries: HScabal-doctest-1.0.6-E57gwmEN5fa2uY0bq8bb44
depends:
    base-4.11.1.0 Cabal-2.2.0.1 filepath-1.4.2 directory-1.3.1.5
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             Cabal-2.2.0.1=e1424ba639ad8048b22840c690086176
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
